@@ -2,6 +2,9 @@ import logging
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
 
+VERBOSE_LOG_FORMAT = "%(asctime)s %(name)s [%(levelname)s] %(message)s"
+SIMPLE_LOG_FORMAT = "[%(levelname)s] %(message)s"
+
 
 def set_stream_logger(name="kinnaird_utils", level=logging.DEBUG, format_string=None):  # pylint: disable=redefined-outer-name
     """
